==> krb5-1.9.1-i486-3sl.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libkadm5srv.so )
( cd usr/lib ; ln -sf libkadm5srv_mit.so libkadm5srv.so )
( cd usr/lib ; rm -rf libk5crypto.so )
( cd usr/lib ; ln -sf libk5crypto.so.3.1 libk5crypto.so )
( cd usr/lib ; rm -rf libgssapi_krb5.so )
( cd usr/lib ; ln -sf libgssapi_krb5.so.2.2 libgssapi_krb5.so )
( cd usr/lib ; rm -rf libkrb5.so.3 )
( cd usr/lib ; ln -sf libkrb5.so.3.3 libkrb5.so.3 )
( cd usr/lib ; rm -rf libkadm5srv_mit.so.8 )
( cd usr/lib ; ln -sf libkadm5srv_mit.so.8.0 libkadm5srv_mit.so.8 )
( cd usr/lib ; rm -rf libk5crypto.so.3 )
( cd usr/lib ; ln -sf libk5crypto.so.3.1 libk5crypto.so.3 )
( cd usr/lib ; rm -rf libcom_err.so.3 )
( cd usr/lib ; ln -sf libcom_err.so.3.0 libcom_err.so.3 )
( cd usr/lib ; rm -rf libgssapi_krb5.so.2 )
( cd usr/lib ; ln -sf libgssapi_krb5.so.2.2 libgssapi_krb5.so.2 )
( cd usr/lib ; rm -rf libkadm5clnt_mit.so.8 )
( cd usr/lib ; ln -sf libkadm5clnt_mit.so.8.0 libkadm5clnt_mit.so.8 )
( cd usr/lib ; rm -rf libkdb5.so )
( cd usr/lib ; ln -sf libkdb5.so.5.0 libkdb5.so )
( cd usr/lib ; rm -rf libkrb5support.so.0 )
( cd usr/lib ; ln -sf libkrb5support.so.0.1 libkrb5support.so.0 )
( cd usr/lib ; rm -rf libkadm5srv_mit.so )
( cd usr/lib ; ln -sf libkadm5srv_mit.so.8.0 libkadm5srv_mit.so )
( cd usr/lib ; rm -rf libkadm5clnt.so )
( cd usr/lib ; ln -sf libkadm5clnt_mit.so libkadm5clnt.so )
( cd usr/lib ; rm -rf libgssrpc.so )
( cd usr/lib ; ln -sf libgssrpc.so.4.1 libgssrpc.so )
( cd usr/lib ; rm -rf libkdb_ldap.so.1 )
( cd usr/lib ; ln -sf libkdb_ldap.so.1.0 libkdb_ldap.so.1 )
( cd usr/lib ; rm -rf libkadm5clnt_mit.so )
( cd usr/lib ; ln -sf libkadm5clnt_mit.so.8.0 libkadm5clnt_mit.so )
( cd usr/lib ; rm -rf libkrb5support.so )
( cd usr/lib ; ln -sf libkrb5support.so.0.1 libkrb5support.so )
( cd usr/lib ; rm -rf libkrb5.so )
( cd usr/lib ; ln -sf libkrb5.so.3.3 libkrb5.so )
( cd usr/lib ; rm -rf libkdb_ldap.so )
( cd usr/lib ; ln -sf libkdb_ldap.so.1.0 libkdb_ldap.so )
( cd usr/lib ; rm -rf libgssrpc.so.4 )
( cd usr/lib ; ln -sf libgssrpc.so.4.1 libgssrpc.so.4 )
( cd usr/lib ; rm -rf libkdb5.so.5 )
( cd usr/lib ; ln -sf libkdb5.so.5.0 libkdb5.so.5 )
( cd usr/lib ; rm -rf libcom_err.so )
( cd usr/lib ; ln -sf libcom_err.so.3.0 libcom_err.so )

==> krb5-1.10.3-i486-1sl.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libcom_err.so )
( cd usr/lib ; ln -sf libcom_err.so.3.0 libcom_err.so )
( cd usr/lib ; rm -rf libverto-k5ev.so )
( cd usr/lib ; ln -sf libverto-k5ev.so.0.0 libverto-k5ev.so )
( cd usr/lib ; rm -rf libkdb_ldap.so )
( cd usr/lib ; ln -sf libkdb_ldap.so.1.0 libkdb_ldap.so )
( cd usr/lib ; rm -rf libkdb_ldap.so.1 )
( cd usr/lib ; ln -sf libkdb_ldap.so.1.0 libkdb_ldap.so.1 )
( cd usr/lib ; rm -rf libgssrpc.so )
( cd usr/lib ; ln -sf libgssrpc.so.4.1 libgssrpc.so )
( cd usr/lib ; rm -rf libverto.so.0 )
( cd usr/lib ; ln -sf libverto.so.0.0 libverto.so.0 )
( cd usr/lib ; rm -rf libgssapi_krb5.so.2 )
( cd usr/lib ; ln -sf libgssapi_krb5.so.2.2 libgssapi_krb5.so.2 )
( cd usr/lib ; rm -rf libkrb5support.so.0 )
( cd usr/lib ; ln -sf libkrb5support.so.0.1 libkrb5support.so.0 )
( cd usr/lib ; rm -rf libkadm5srv_mit.so.8 )
( cd usr/lib ; ln -sf libkadm5srv_mit.so.8.0 libkadm5srv_mit.so.8 )
( cd usr/lib ; rm -rf libkadm5clnt.so )
( cd usr/lib ; ln -sf libkadm5clnt_mit.so libkadm5clnt.so )
( cd usr/lib ; rm -rf libkdb5.so )
( cd usr/lib ; ln -sf libkdb5.so.6.0 libkdb5.so )
( cd usr/lib ; rm -rf libkadm5srv.so )
( cd usr/lib ; ln -sf libkadm5srv_mit.so libkadm5srv.so )
( cd usr/lib ; rm -rf libverto.so )
( cd usr/lib ; ln -sf libverto.so.0.0 libverto.so )
( cd usr/lib ; rm -rf libkadm5srv_mit.so )
( cd usr/lib ; ln -sf libkadm5srv_mit.so.8.0 libkadm5srv_mit.so )
( cd usr/lib ; rm -rf libverto-k5ev.so.0 )
( cd usr/lib ; ln -sf libverto-k5ev.so.0.0 libverto-k5ev.so.0 )
( cd usr/lib ; rm -rf libk5crypto.so )
( cd usr/lib ; ln -sf libk5crypto.so.3.1 libk5crypto.so )
( cd usr/lib ; rm -rf libcom_err.so.3 )
( cd usr/lib ; ln -sf libcom_err.so.3.0 libcom_err.so.3 )
( cd usr/lib ; rm -rf libkrb5support.so )
( cd usr/lib ; ln -sf libkrb5support.so.0.1 libkrb5support.so )
( cd usr/lib ; rm -rf libgssrpc.so.4 )
( cd usr/lib ; ln -sf libgssrpc.so.4.1 libgssrpc.so.4 )
( cd usr/lib ; rm -rf libkadm5clnt_mit.so.8 )
( cd usr/lib ; ln -sf libkadm5clnt_mit.so.8.0 libkadm5clnt_mit.so.8 )
( cd usr/lib ; rm -rf libk5crypto.so.3 )
( cd usr/lib ; ln -sf libk5crypto.so.3.1 libk5crypto.so.3 )
( cd usr/lib ; rm -rf libkadm5clnt_mit.so )
( cd usr/lib ; ln -sf libkadm5clnt_mit.so.8.0 libkadm5clnt_mit.so )
( cd usr/lib ; rm -rf libgssapi_krb5.so )
( cd usr/lib ; ln -sf libgssapi_krb5.so.2.2 libgssapi_krb5.so )
( cd usr/lib ; rm -rf libkdb5.so.6 )
( cd usr/lib ; ln -sf libkdb5.so.6.0 libkdb5.so.6 )
( cd usr/lib ; rm -rf libkrb5.so.3 )
( cd usr/lib ; ln -sf libkrb5.so.3.3 libkrb5.so.3 )
( cd usr/lib ; rm -rf libkrb5.so )
( cd usr/lib ; ln -sf libkrb5.so.3.3 libkrb5.so )
